@@ -29,7 +29,7 @@ class LoginView(views.APIView):
             'response_type': 'code',
             'scope': settings.HUB_OAUTH_SCOPES,
             'state': state,
-            'url': request.build_absolute_uri()
+            'url': request.query_params.get('url', '/')
         }
 
         redirect_uri = settings.HUB_BASE_FRONT_URI + settings.HUB_OAUTH_AUTHORIZE_URI
